@@ -88,5 +88,13 @@ class FeatureUpdater:
         return Mdf.set_index(partition_by)
 
 
-def FeatureSaver(freq):
-    return FeatureUpdater(freq=freq, is_alpha=True)
+class FeatureSaver(FeatureUpdater):
+
+    def __init__(self, freq):
+        super().__init__(freq=freq)
+
+    def save_alpha(self, alpha, alpha_name):
+        alpha = alpha.rename(columns={"value": alpha_name})
+        self.save_values(alpha, cal_config[self.freq]["col_name"], "stockcode")
+
+print("res")
\ No newline at end of file
